pub struct BumpInput {
pub workspace_path: String,
pub version: Option<String>,
pub bump: Option<String>,
pub no_changelog: bool,
pub no_commit: bool,
pub no_tag: bool,
pub commit_template: Option<String>,
pub tag_template: Option<String>,
pub dry_run: bool,
pub allow_version_drift: bool,
pub allow_dirty: bool,
}Expand description
Bump input.
Fields
workspace_path: StringWorkspace root.
version: Option<String>Force version.
bump: Option<String>Optional bump strategy.
no_changelog: boolSkip changelog generation.
no_commit: boolSkip commit creation.
no_tag: boolSkip tag creation.
commit_template: Option<String>Commit message template.
tag_template: Option<String>Tag template.
dry_run: boolDry run.
allow_version_drift: boolAllow workspace version drift from the last release tag.
allow_dirty: boolAllow mutating release steps on a dirty working tree.